@@ -27,7 +27,7 @@ Base_Spell = {
 	end,
 
 	GetDamage = function(self, Source, Level)
-		return math.floor((self.DamageBase + (Level - 1) * self.DamagePerLevel + math.pow(Level, self.DamagePower) * self.DamageScale) * self:GetDamagePower(Source, Level))
+		return math.floor((self.DamageBase + (Level - 1) * self.DamagePerLevel + (Level ^ self.DamagePower) * self.DamageScale) * self:GetDamagePower(Source, Level))
 	end,
 
 	GetMinDamage = function(self, Source, Level)
